﻿<%@ Page Language="C#" %>
<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Data.OleDb" %>

<script runat="server">

    protected void Page_Load(object sender, System.EventArgs e)
    {

        DataSet ExportErrors = new DataSet("ExportErrors");
        DataTable TblErrors = ExportErrors.Tables.Add("ErrorLogs");

        DataColumn Col = default(DataColumn);
        Col = TblErrors.Columns.Add("ErrorID", typeof(Int32));
        Col.AutoIncrement = true;
        Col.AutoIncrementSeed = 1;
        Col.AutoIncrementStep = 1;

        Col = TblErrors.Columns.Add("IsHtml", typeof(bool));
        Col.DefaultValue = false;

        TblErrors.Columns.Add("ErrorTitle", typeof(string));
        TblErrors.Columns.Add("ErrorMessage", typeof(string));
        TblErrors.Columns.Add("ExportData", typeof(string));
        TblErrors.Columns.Add("StackTrace", typeof(string));

        if (Request.Files.Count > 0)
        {

            DataSet Ds = new DataSet();
            Ds.ReadXml(Request.Files[0].InputStream);

            OleDbConnectionStringBuilder ConStrBuilder = new OleDbConnectionStringBuilder();
            ConStrBuilder.Provider = "Microsoft.Jet.OLEDB.4.0";
            ConStrBuilder.DataSource = Path.Combine(Request.PhysicalApplicationPath, "DemoData.mdb");
            ConStrBuilder.PersistSecurityInfo = false;

            OleDbConnection Conn = new OleDbConnection(ConStrBuilder.ConnectionString);

            Conn.Open();

            foreach (DataRow Row in Ds.Tables["STOCK"].Rows)
            {
                bool IsInsert = false;

                OleDbCommand Cmd = new OleDbCommand("SELECT COUNT(ProductCode) FROM Products WHERE ProductCode=?", Conn);
                Cmd.Parameters.Add(new OleDbParameter("@ProductCode", Row["STOCK_CODE"])).DbType = DbType.String;

                bool RecordExists = Convert.ToInt32(Cmd.ExecuteScalar()) > 0;


                if (RecordExists)
                {
                    IsInsert = false;
                    Cmd.CommandText = "UPDATE Products SET Description=?, SalesPrice=?, Category=? WHERE ProductCode=?";
                }
                else
                {
                    IsInsert = true;
                    Cmd.CommandText = "INSERT INTO Products (Description, SalesPrice, Category, ProductCode) VALUES(?, ?, ?, ?)";
                }

                Cmd.Parameters.Clear();

                try
                {
                    Cmd.Parameters.Add(new OleDbParameter("@Description", Row["DESCRIPTION"])).DbType = DbType.String;
                    Cmd.Parameters.Add(new OleDbParameter("@SalesPrice", Row["SALES_PRICE"])).DbType = DbType.Double;
                    Cmd.Parameters.Add(new OleDbParameter("@Category", Row["STOCK_CAT"])).DbType = DbType.String;
                    Cmd.Parameters.Add(new OleDbParameter("@ProductCode", Row["STOCK_CODE"])).DbType = DbType.String;
                    Cmd.ExecuteNonQuery();
                }
                catch (Exception ex)
                {
                    DataRow NewErrorRow = TblErrors.NewRow();
                    NewErrorRow["ErrorTitle"] = (IsInsert ? "Insert Record Failed" : "Update Record Failed");
                    NewErrorRow["ErrorMessage"] = ex.Message;
                    NewErrorRow["StackTrace"] = ex.StackTrace;
                    NewErrorRow["ExportData"] = "";
                    foreach (DataColumn Column in Row.Table.Columns)
                    {
                        NewErrorRow["ExportData"] += Column.ColumnName + "=" + Row[Column.ColumnName] + "\n";
                    }
                    TblErrors.Rows.Add(NewErrorRow);
                }
            }



            Conn.Close();
        }


        Response.Clear();
        Response.Write("<?xml version=\"1.0\" standalone=\"yes\"?>" + "\n" + ExportErrors.GetXml());
        Response.End();

    } 

</script>

<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
    <title></title>
</head>
<body>
</body>
</html>
